@@ -1,5 +1,4 @@
 __title__       = "pproxy"
-__version__     = "2.4.6"
 __license__     = "MIT"
 __description__ = "Proxy server that can tunnel among remote servers by regex rules."
 __keywords__    = "proxy socks http shadowsocks shadowsocksr ssr redirect pf tunnel cipher ssl udp"
@@ -7,4 +6,14 @@ __author__      = "Qian Wenjie"
 __email__       = "qianwenjie@gmail.com"
 __url__         = "https://github.com/qwj/python-proxy"
 
+try:
+    from setuptools_scm import get_version
+    __version__ = get_version()
+except Exception:
+    try:
+        from pkg_resources import get_distribution
+        __version__ = get_distribution('pproxy').version
+    except Exception:
+        __version__ = 'unknown'
+
 __all__ = ['__version__', '__description__', '__url__']
